.. gromacs_py documentation master file, created by
   sphinx-quickstart on Fri Jun  1 16:36:00 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


.. include:: ../README.rst


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
